@@ -1,7 +1,6 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 from proteus import Model
-
 from trytond.modules.company.tests.tools import get_company
 
 
@@ -10,10 +9,10 @@ def add_deposit_accounts(accounts, company=None, config=None):
     Account = Model.get('account.account', config=config)
 
     if not company:
-        company = get_company()
+        company = get_company(config=config)
 
     accounts['deposit'], = Account.find([
-            ('kind', '=', 'deposit'),
+            ('type.deposit', '=', True),
             ('company', '=', company.id),
             ('name', '=', 'Deposit'),
             ])
